pascal\_voc\_tools.Evaluater package
====================================

Submodules
----------

pascal\_voc\_tools.Evaluater.tools module
-----------------------------------------

.. automodule:: pascal_voc_tools.Evaluater.tools
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pascal_voc_tools.Evaluater
   :members:
   :undoc-members:
   :show-inheritance:
